@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2012 by Dominique Dumont, Krzysztof Tyszecki.
+# This software is Copyright (c) 2013 by Dominique Dumont, Krzysztof Tyszecki.
 #
 # This is free software, licensed under:
 #
@@ -27,10 +27,10 @@
 
 package Config::Model::Annotation;
 {
-  $Config::Model::Annotation::VERSION = '2.029';
+  $Config::Model::Annotation::VERSION = '2.040';
 }
 
-use Any::Moose ;
+use Mouse ;
 use English ;
 
 use File::Path;
@@ -57,7 +57,7 @@ Config::Model::Annotation - Read and write configuration annotations
 
 =head1 VERSION
 
-version 2.029
+version 2.040
 
 =head1 SYNOPSIS
 
@@ -293,7 +293,7 @@ sub load {
     }
 }
 
-no Any::Moose ;
+no Mouse ;
 
 __PACKAGE__ -> meta->make_immutable;
 
