@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2012 by Dominique Dumont, Krzysztof Tyszecki.
+# This software is Copyright (c) 2013 by Dominique Dumont, Krzysztof Tyszecki.
 #
 # This is free software, licensed under:
 #
@@ -28,7 +28,7 @@
 
 package Config::Model::Exception ;
 {
-  $Config::Model::Exception::VERSION = '2.029';
+  $Config::Model::Exception::VERSION = '2.040';
 }
 use warnings ;
 use strict;
@@ -156,7 +156,7 @@ Config::Model::Exception::Internal->Trace(1);
 
 package Config::Model::Exception::Syntax ;
 {
-  $Config::Model::Exception::Syntax::VERSION = '2.029';
+  $Config::Model::Exception::Syntax::VERSION = '2.040';
 }
 
 sub full_message {
@@ -173,7 +173,7 @@ sub full_message {
 
 package Config::Model::Exception::Any ;
 {
-  $Config::Model::Exception::Any::VERSION = '2.029';
+  $Config::Model::Exception::Any::VERSION = '2.040';
 }
 
 sub full_message {
@@ -205,7 +205,7 @@ sub xpath_message {
 
 package Config::Model::Exception::LoadData ;
 {
-  $Config::Model::Exception::LoadData::VERSION = '2.029';
+  $Config::Model::Exception::LoadData::VERSION = '2.040';
 }
 
 sub full_message {
@@ -225,7 +225,7 @@ sub full_message {
 
 package Config::Model::Exception::Model ;
 {
-  $Config::Model::Exception::Model::VERSION = '2.029';
+  $Config::Model::Exception::Model::VERSION = '2.040';
 }
 
 sub full_message {
@@ -234,7 +234,7 @@ sub full_message {
     my $obj = $self->object ;
     my $msg ;
     if ($obj->isa('Config::Model::Node')) {
-	$msg = "Node '".$obj->name."' ";
+	$msg = "Node '".$obj->name."' of class ".$obj->config_class_name.' ';
     }
     else {
 	my $element = $obj->element_name ;
@@ -251,7 +251,7 @@ sub full_message {
 
 package Config::Model::Exception::Load ;
 {
-  $Config::Model::Exception::Load::VERSION = '2.029';
+  $Config::Model::Exception::Load::VERSION = '2.040';
 }
 
 sub full_message {
@@ -273,7 +273,7 @@ sub full_message {
 
 package Config::Model::Exception::RestrictedElement ;
 {
-  $Config::Model::Exception::RestrictedElement::VERSION = '2.029';
+  $Config::Model::Exception::RestrictedElement::VERSION = '2.040';
 }
 
 sub full_message {
@@ -293,7 +293,7 @@ sub full_message {
 
 package Config::Model::Exception::UnavailableElement ;
 {
-  $Config::Model::Exception::UnavailableElement::VERSION = '2.029';
+  $Config::Model::Exception::UnavailableElement::VERSION = '2.040';
 }
 
 sub full_message {
@@ -316,7 +316,7 @@ sub full_message {
 
 package Config::Model::Exception::ObsoleteElement ;
 {
-  $Config::Model::Exception::ObsoleteElement::VERSION = '2.029';
+  $Config::Model::Exception::ObsoleteElement::VERSION = '2.040';
 }
 
 sub full_message {
@@ -338,7 +338,7 @@ sub full_message {
 
 package Config::Model::Exception::UnknownElement ;
 {
-  $Config::Model::Exception::UnknownElement::VERSION = '2.029';
+  $Config::Model::Exception::UnknownElement::VERSION = '2.040';
 }
 use Carp;
 
@@ -373,7 +373,7 @@ sub full_message {
 
     $msg .= $self->description. " '". $self->element. "'." ;
 
-    $msg .= " Either you file has an error or $class_name model is lagging behind. "
+    $msg .= " Either your file has an error or $class_name model is lagging behind. "
         ."In the latter case, please submit a bug report or fix the model. See cme man "
         ."page for details.\n";
 
@@ -409,7 +409,7 @@ sub full_message {
 
 package Config::Model::Exception::UnknownId ;
 {
-  $Config::Model::Exception::UnknownId::VERSION = '2.029';
+  $Config::Model::Exception::UnknownId::VERSION = '2.040';
 }
 
 sub full_message {
@@ -438,7 +438,7 @@ sub full_message {
 
 package Config::Model::Exception::WrongType ;
 {
-  $Config::Model::Exception::WrongType::VERSION = '2.029';
+  $Config::Model::Exception::WrongType::VERSION = '2.040';
 }
 
 sub full_message {
@@ -462,7 +462,7 @@ sub full_message {
 
 package Config::Model::Exception::Xml ;
 {
-  $Config::Model::Exception::Xml::VERSION = '2.029';
+  $Config::Model::Exception::Xml::VERSION = '2.040';
 }
 
 sub full_message {
@@ -490,7 +490,7 @@ Config::Model::Exception - Exception mechanism for configuration model
 
 =head1 VERSION
 
-version 2.029
+version 2.040
 
 =head1 SYNOPSIS
 
