@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2012 by Dominique Dumont, Krzysztof Tyszecki.
+# This software is Copyright (c) 2013 by Dominique Dumont, Krzysztof Tyszecki.
 #
 # This is free software, licensed under:
 #
@@ -9,9 +9,9 @@
 #
 package Config::Model::HashId ;
 {
-  $Config::Model::HashId::VERSION = '2.011';
+  $Config::Model::HashId::VERSION = '2.040';
 }
-use Any::Moose ;
+use Mouse ;
 use namespace::autoclean;
 
 use Config::Model::Exception ;
@@ -32,6 +32,13 @@ has [qw/morph ordered/] => (is => 'ro', isa => 'Bool' ) ;
 sub BUILD {
     my $self = shift;
 
+    # foreach my $wrong (qw/migrate_values_from/) {
+        # Config::Model::Exception::Model->throw (
+            # object => $self,
+            # error =>  "Cannot use $wrong with ".$self->get_type." element"
+        # ) if defined $self->{$wrong};
+    # }
+
     # could use "required", but we'd get a Moose error instead of a Config::Model
     # error
     Config::Model::Exception::Model->throw 
@@ -74,6 +81,35 @@ sub set_properties {
     }
 }
 
+sub _migrate {
+    my $self = shift;
+
+    return if $self->{migration_done};
+    
+    # migration must be done *after* initial load to make sure that all data
+    # were retrieved from the file before migration. 
+    return if $self->instance->initial_load ;
+    $self->{migration_done} = 1;
+    
+    if ($self->{migrate_keys_from}) { 
+        my $followed = $self->safe_typed_grab(param => 'migrate_keys_from', check => 'no') ;
+        if ($logger->is_debug) {
+            $logger ->debug($self->name," migrate keys from ",$followed->name);
+        }
+
+        map { $self->_store($_, undef) unless $self->_defined($_) } $followed -> fetch_all_indexes ;
+    }
+    elsif ( $self->{migrate_values_from}) {
+        my $followed = $self->safe_typed_grab(param => 'migrate_values_from', check => 'no') ;
+        $logger ->debug($self->name," migrate values from ",$followed->name) if $logger->is_debug;
+        foreach my $item ( $followed -> fetch_all_indexes ) {
+            next if $self->exists($item) ; # don't clobber existing entries
+            my $data = $followed->fetch_with_id($item) -> dump_as_data(check => 'no') ;
+            $self->fetch_with_id($item)->load_data($data) ;
+        }
+    }
+
+}
 
 sub get_type {
     my $self = shift;
@@ -81,12 +117,13 @@ sub get_type {
 }
 
 
+# important: return the actual size (not taking into account auto-created stuff)
 sub fetch_size {
     my $self = shift;
     return scalar keys %{$self->{data}} ;
 }
 
-sub _get_all_indexes {
+sub _fetch_all_indexes {
     my $self = shift;
     return $self->{ordered} ? @{$self->{list}}
       :                    sort keys %{$self->{data}} ;
@@ -173,7 +210,7 @@ sub firstkey {
     $self->create_default if defined $self->{default};
 
     # reset "each" iterator (to be sure, map is also an iterator)
-    my @list = $self->_get_all_indexes ;
+    my @list = $self->_fetch_all_indexes ;
     $self->{each_list} = \@list ;
     return shift @list ;
 }
@@ -191,7 +228,7 @@ sub nextkey {
     return $res if defined $res ;
 
     # reset list for next call to next_keys
-    $self->{each_list} = [ $self->_get_all_indexes  ] ;
+    $self->{each_list} = [ $self->_fetch_all_indexes  ] ;
 
     return ;
 }
@@ -219,6 +256,8 @@ sub swap {
             $self->{list}[$idx] = $key1 ;
         }
     }
+
+    $self->notify_change(note => "swap ordered hash keys $key1 and $key2")
 }
 
 
@@ -241,6 +280,8 @@ sub move {
         delete $self->{warning_hash}{$from} ;
         # update index_value attribute in moved objects
         $self->{data}{$to}->index_value($to) ;
+        
+        $self->notify_change(note => "rename key from $from to $to");
 
         # data_mode is preset or layered or user. Actually only user
         # mode makes sense here
@@ -280,6 +321,11 @@ sub move_after {
     my $self = shift ;
     my ($key_to_move,$ref_key) = @_ ;
 
+    if (not $self->ordered) {
+        $logger->warn("called move_after on unordered hash") ;
+        return ;
+    }
+
     foreach my $k (@_) {
         Config::Model::Exception::User
             -> throw (
@@ -294,6 +340,7 @@ sub move_after {
 
     my $list = $self->{list} ;
 
+    my $msg ;
     if (defined $ref_key) {
         for (my $idx = 0; $idx <= $#$list; $idx ++ ) {
             if ($list->[$idx] eq $ref_key) {
@@ -301,9 +348,16 @@ sub move_after {
                 last;
             }
         }
+
+        $msg = "moved key $key_to_move after $ref_key" ;
     } else {
         unshift @$list , $key_to_move ;
+        $msg = "moved key $key_to_move at beginning" ;
     }
+
+
+    $self->notify_change( note => $msg ) ;
+
 }
 
 
@@ -311,6 +365,11 @@ sub move_up {
     my $self = shift ;
     my ($key) = @_ ;
 
+    if (not $self->ordered) {
+        $logger->warn("called move_up on unordered hash") ;
+        return ;
+    }
+
     Config::Model::Exception::User
         -> throw (
                   object => $self,
@@ -324,9 +383,13 @@ sub move_up {
         if ($list->[$idx] eq $key) {
             $list->[$idx]   = $list->[$idx-1];
             $list->[$idx-1] = $key ;
+            $self->notify_change(note => "moved up key $key") ;
             last ;
         }
     }
+
+    # notify_change is placed in the loop so the notification
+    # is not sent if the user tries to move up idx 0
 }
 
 
@@ -334,6 +397,11 @@ sub move_down {
     my $self = shift ;
     my ($key) = @_ ;
 
+    if (not $self->ordered) {
+        $logger->warn("called move_down on unordered hash") ;
+        return ;
+    }
+
     Config::Model::Exception::User
         -> throw (
                   object => $self,
@@ -347,15 +415,21 @@ sub move_down {
         if ($list->[$idx] eq $key) {
             $list->[$idx]   = $list->[$idx+1];
             $list->[$idx+1] = $key ;
+            $self->notify_change(note => "moved down key $key") ;
             last ;
         }
     }
+
+    # notify_change is placed in the loop so the notification
+    # is not sent if the user tries to move past last idx
 }
 
 
 sub load_data {
     my $self = shift ;
-    my $data = shift ;
+    my %args = @_ > 1 ? @_ : ( data => shift) ;
+    my $data       = delete $args{data};
+    my $check = $self->_check_check($args{check}) ;
 
     if (ref ($data) eq 'HASH') {
         my @load_keys ;
@@ -377,7 +451,7 @@ sub load_data {
                       ") will load idx @load_keys from hash ref".$from);
         foreach my $elt (@load_keys) {
             my $obj = $self->fetch_with_id($elt) ;
-            $obj -> load_data($data->{$elt}) ;
+            $obj -> load_data(%args, data => $data->{$elt}) ;
         }
     }
     elsif ( $self->{ordered} and ref ($data) eq 'ARRAY') {
@@ -387,7 +461,7 @@ sub load_data {
         while ( $idx < @$data ) {
             my $elt = $data->[$idx++];
             my $obj = $self->fetch_with_id($elt) ;
-            $obj -> load_data($data->[$idx++]) ;
+            $obj -> load_data(%args, data => $data->[$idx++]) ;
         }
     }
     elsif (defined $data) {
@@ -417,7 +491,7 @@ Config::Model::HashId - Handle hash element for configuration model
 
 =head1 VERSION
 
-version 2.011
+version 2.040
 
 =head1 SYNOPSIS
 
@@ -484,7 +558,7 @@ an ordered hash will be ignored. Ignored for non ordered hash.
 Move the key down in a ordered hash. Attempt to move up the last key of
 an ordered hash will be ignored. Ignored for non ordered hash.
 
-=head2 load_data ( hash_ref | array_ref )
+=head2 load_data ( data => ( hash_ref | array_ref ) [ , check => ... , ... ])
 
 Load check_list as a hash ref for standard hash. 
 
@@ -497,6 +571,8 @@ or
 
   { __order => ['a','b'], b => 'bar', a => 'foo' }
 
+load_data can also be called with a single ref parameter.
+
 =head1 AUTHOR
 
 Dominique Dumont, (ddumont at cpan dot org)
