@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2012 by Dominique Dumont, Krzysztof Tyszecki.
+# This software is Copyright (c) 2013 by Dominique Dumont, Krzysztof Tyszecki.
 #
 # This is free software, licensed under:
 #
@@ -9,15 +9,16 @@
 #
 package Config::Model::Instance;
 {
-  $Config::Model::Instance::VERSION = '2.010';
+  $Config::Model::Instance::VERSION = '2.040';
 }
 #use Scalar::Util qw(weaken) ;
 
-use Any::Moose ;
+use Mouse ;
 use namespace::autoclean;
-use Any::Moose '::Util::TypeConstraints';
-use Any::Moose 'X::StrictConstructor' ;
+use Mouse::Util::TypeConstraints;
+use MouseX::StrictConstructor;
 
+use Text::Diff ;
 use File::Path;
 use Log::Log4perl qw(get_logger :levels);
 
@@ -74,19 +75,82 @@ has [qw/preset layered/] => (
     default => 0,
 );
 
-has needs_save => (
+has changes => (
+    is =>'ro',
+    isa => 'ArrayRef',
+    traits => ['Array'],
+    default => sub { [] },
+    handles => {
+        add_change => 'push',
+        c_count => 'count' ,
+        #needs_save => 'count' ,
+        clear_changes => 'clear' ,
+    }
+);
+
+sub needs_save {
+    my $self = shift;
+    my $arg = shift ;
+    if (defined $arg) {
+        if ($arg) {
+            carp "replace needs_save(1) call with add_change" ;
+            $self->add_change() ; # may not work
+        }
+        else {
+            carp "replace needs_save(0) call with clear_changes" ;
+            $self->clear_changes ;
+        }
+    }
+    return $self->c_count ;
+}
+
+has errors => (
+    is => 'ro',
+    isa => 'HashRef',
+    traits => ['Hash'],
+    default => sub { {} },
+    handles => {
+        _set_error => 'set',
+        has_error => 'count' ,
+        clear_errors => 'clear' ,
+        error_paths => 'keys'
+    }
+) ;
+
+sub add_error {
+    my $self = shift;
+    $self->_set_error(shift, '') ;
+}
+
+sub error_messages {
+    my $self = shift ;
+    my @errs = map {"$_: " . $self->config_root->grab($_)->error_msg} $self->error_paths ;
+    return wantarray ? @errs : join("\n", @errs) ;
+}
+
+has on_change_cb => (
     is => 'rw',
-    isa => 'Bool' ,
-    default => 0,
+    isa => 'Maybe[CodeRef]',
 );
 
 # initial_load mode: when data is loaded the first time
 has initial_load => ( 
-    is => 'ro',
+    is => 'rw',
     isa => 'Bool' ,
-    default => 1,
+    default => 0,
+    trigger => \&_trace_initial_load,
+    traits => [qw/Bool/],
+    handles => {
+        initial_load_start => 'set',
+        initial_load_stop => 'unset',
+    }
 ) ;
 
+sub _trace_initial_load { 
+    my ($self,$n,$o) = @_;
+    $logger->debug("switched to $n") ;
+}
+
 # This array holds a set of sub ref that will be invoked when
 # the users requires to write all configuration tree in their
 # backend storage.
@@ -102,7 +166,7 @@ has _write_back => (
 );
 
 # used for auto_read auto_write feature
-has [qw/name root_dir config_file backend/] => (
+has [qw/name root_dir config_file backend backup/] => (
     is => 'ro',
     isa => 'Maybe[Str]' ,
 );
@@ -124,6 +188,7 @@ has tree => (
     isa => 'Config::Model::Node',
     builder => 'reset_config' ,
     reader => 'config_root' ,
+    handles => [qw/apply_fixes/] ,
 );
 
 sub reset_config {
@@ -133,7 +198,8 @@ sub reset_config {
         config_class_name => $self->{root_class_name},
         instance          => $self,
         container         => $self,
-        skip_read         => $self->{skip_read},
+        skip_read         => $self->skip_read,
+        check             => $self->read_check,
         config_file       => $self->{config_file} ,
     );
 }
@@ -233,18 +299,6 @@ sub _stuff_clear {
 
 }
 
-sub initial_load_start {
-    my $self = shift ;
-    $logger->info("Start initial_load mode");
-    $self->{initial_load} = 1;
-}
-
-sub initial_load_stop {
-    my $self = shift ;
-    $logger->info("Stopping initial_load mode");
-    $self->{initial_load} = 0;
-}
-
 
 sub load {
     my $self = shift ;
@@ -300,8 +354,41 @@ sub write_root_dir {
 # FIXME: record changes to implement undo/redo ?
 sub notify_change {
     my $self = shift ;
-    $change_logger->debug("called for  instance ",$self->name) if $change_logger->is_debug ;
-    $self->{needs_save} = 1;
+    my %args = @_ ;
+    if ($change_logger->is_debug) {
+        $change_logger->debug("in instance ",$self->name, 'for path ',$args{path}) ;
+    }
+    $self->add_change( \%args ) ;
+    my $cb = $self->on_change_cb ;
+    $cb->(@_) if $cb ;
+}
+
+sub list_changes {
+    my $self = shift;
+    my $l = $self->changes ;
+    my @all ;
+
+    foreach my $c (@$l) {
+        my $path = $c->{path} ;
+        
+        # don't list change without further info (like nodes)
+        next unless keys %$c > 1 ;
+        my $vt = $c->{value_type} || '' ;
+        my ($o,$n) =  map { $_ || '<undef>' ;} ($c->{old},$c->{new}) ;
+        
+        if ($vt eq 'string' and ($o =~ /\n/ or $n =~ /\n/) ) {
+            # append \n if needed so diff works as expected
+            map { $_ .= "\n" unless /\n$/ ;} ($o,$n) ;
+            my $diff = diff \$o, \$n ;
+            push @all, "$path :" . ($c->{note} ? " # $c->{note}" : ''). "\n". $diff;
+        }
+        elsif (exists $c->{old} or exists $c->{new}) {
+            map { s/\n.*/.../s; } ($o,$n) ;
+            push @all, "$path: '$o' -> '$n'" . ($c->{note} ? " # $c->{note}" : '');
+        }
+    }
+
+    return wantarray ? @all : join("\n",@all) ;
 }
 
 
@@ -335,51 +422,13 @@ sub write_back {
             config_file => $self->{config_file} ,
             backend => $force_backend,
             force => $force_write,
+            backup => $self->backup,
         );
     }
-    $self->needs_save(0) ;
+    $self-> clear_changes;
 }
 
 
-sub apply_fixes {
-    my $self = shift ;
-
-    # define leaf call back
-    my $fix_leaf = sub { 
-      my ($scanner, $data_ref, $node,$element_name,$index, $leaf_object) = @_ ;
-      $leaf_object->apply_fixes ;
-    } ;
-
-    my $fix_hash = sub {
-        my ( $scanner, $data_r, $node, $element, @keys ) = @_;
-
-        return unless @keys;
-
-        # leaves must be fixed before the hash, hence the 
-        # calls to scan_hash before apply_fixes
-        map {$scanner->scan_hash($data_r,$node,$element,$_)} @keys ;
-
-        $node->fetch_element($element)->apply_fixes ;
-    } ;
-    
-    my $fix_list = sub {
-        my ( $scanner, $data_r, $node, $element, @keys ) = @_;
-
-        return unless @keys;
-
-        map {$scanner->scan_list($data_r,$node,$element,$_)} @keys ;
-        $node->fetch_element($element)->apply_fixes ;
-    } ;
-    
-   my $scan = Config::Model::ObjTreeScanner-> new ( 
-        hash_element_cb => $fix_hash ,
-        list_element_cb => $fix_list ,
-        leaf_cb => $fix_leaf ,
-        check => 'no',
-    ) ;
-
-    $scan->scan_node(undef, $self->config_root) ;
-}
 
 __PACKAGE__->meta->make_immutable;
 
@@ -397,7 +446,7 @@ Config::Model::Instance - Instance of configuration tree
 
 =head1 VERSION
 
-version 2.010
+version 2.040
 
 =head1 SYNOPSIS
 
@@ -469,6 +518,19 @@ configuration tree.
 
 'yes', 'skip' or 'no'
 
+=item on_change_cb
+
+Call back this function whenever C<notify_change> is called. Called with
+arguments: C<< name => <root node element name>, index => <index_value> >>
+
+=item error_paths
+
+Returns a list of tree items that currently have an error.
+
+=item error_messages
+
+Returns a list of error messages from the tree content.
+
 =back
 
 Note that the root directory specified within the configuration model
@@ -594,20 +656,16 @@ configuration model, then load all configuration data.
 
 This feature enables you to declare with the model a way to load
 configuration data (and to write it back). See
-L<Config::Model::AutoRead> for details.
-
-=head2 read_root_dir()
-
-Returns root directory where configuration data is read from.
+L<Config::Model::BackendMgr> for details.
 
 =head2 backend()
 
 Get the preferred backend method for this instance (as passed to the
 constructor).
 
-=head2 write_root_dir()
+=head2 root_dir()
 
-Returns root directory where configuration data is written to.
+Returns root directory where configuration data is read from or written to.
 
 =head2 register_write_back ( node_location )
 
@@ -622,7 +680,7 @@ Notify that some data has changed in the tree.
 
 Try to run all subroutines registered with C<register_write_back> to
 write the configuration information until one succeeds (returns
-true). (See L<Config::Model::AutoRead> for details).
+true). (See L<Config::Model::BackendMgr> for details).
 
 You can specify here a pseudo root directory or another config
 directory to write configuration data back with C<root> and
@@ -641,6 +699,15 @@ C<write_back> will croak if no write call-back are known.
 Scan the tree and apply fixes that are attached to warning specifications. 
 See C<warn_if_match> or C<warn_unless_match> in L<Config::Model::Value/>.
 
+=head2 needs_save
+
+Returns 1 (or more) if the instance contains data that needs to be saved.
+
+=head2 list_changes
+
+In list context, returns a array ref of strings describing the changes. 
+In scalar context, returns a big string. Useful to print.
+
 =head1 AUTHOR
 
 Dominique Dumont, (ddumont at cpan dot org)
