@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2012 by Dominique Dumont, Krzysztof Tyszecki.
+# This software is Copyright (c) 2013 by Dominique Dumont, Krzysztof Tyszecki.
 #
 # This is free software, licensed under:
 #
@@ -9,9 +9,9 @@
 #
 package Config::Model::ListId ;
 {
-  $Config::Model::ListId::VERSION = '2.021';
+  $Config::Model::ListId::VERSION = '2.040';
 }
-use Any::Moose ;
+use Mouse ;
 use namespace::autoclean;
 
 use Config::Model::Exception ;
@@ -234,6 +234,7 @@ sub move {
     if ($ok or $check eq 'no') {
         $self->_store($to, $moved) ;
         $moved->index_value($to) ;
+        $self->notify_change(note => "moved from index $from to $to") ;
         my $imode = $self->instance->get_data_mode ;
         $self->set_data_mode( $to, $imode ) ;
     }
@@ -304,8 +305,7 @@ sub swap {
     $self->{data}[$ida] = $objb ;
     $self->{data}[$idb] = $obja ;
     
-    $self->notify_change(index => $ida) ;
-    $self->notify_change(index => $idb) ;
+    $self->notify_change(note => "swapped index $ida and $idb") ;
 }
 
 #die "check index number after wap";
@@ -359,13 +359,21 @@ sub create_default {
 
 sub load_data {
     my $self = shift ;
-    my $raw_data = shift ;
-    my $check = shift ;
+    my %args = @_ > 1 ? @_ : ( data => shift) ;
+    my $raw_data    = delete $args{data};
+    my $check = $self->_check_check($args{check}) ;
 
     my $data = ref($raw_data) eq 'ARRAY' ? $raw_data 
+             : $args{split_reg}          ? [ split $args{split_reg}, $raw_data ]
              : defined $raw_data         ? [ $raw_data ] 
              :                             undef; 
 
+    Config::Model::Exception::LoadData -> throw (
+        object => $self,
+        message => "load_data called with non expected data. Expected array ref or scalar",
+        wrong_data => $raw_data ,
+    ) unless defined $data;
+
     $self->clear ;
 
     my $idx = 0;
@@ -373,7 +381,7 @@ sub load_data {
         "0..$#$data");
     foreach my $item (@$data ) {
         my $obj = $self->fetch_with_id($idx++) ;
-        $obj -> load_data($item, $check) ;
+        $obj -> load_data(%args, data => $item) ;
     }   
 }
 
@@ -392,7 +400,7 @@ Config::Model::ListId - Handle list element for configuration model
 
 =head1 VERSION
 
-version 2.021
+version 2.040
 
 =head1 SYNOPSIS
 
@@ -502,11 +510,18 @@ Swap 2 elements within the array
 
 Remove an element from the list. Equivalent to C<splice @list,$idx,1>
 
-=head2 load_data ( array_ref | data )
+=head2 load_data ( data => ( ref | scalar ) [, check => ... ] [ , split_reg => $re ] )
 
-Clear and load list from data contained in the array ref. If a scalar
-or a hash ref is passed, the list is cleared and the data is stored in
-the first element of the list.
+Clear and load list from data contained in the C<data> array ref. If a scalar or a hash ref
+is passed, the list is cleared and the data is stored in
+the first element of the list. If split_reg is specified, the scalar will be split
+to load the array.
+
+For instance
+
+   $elt->load_data( data => 'foo,bar', split_reg => qr(,) ) ;
+
+will load C< [ 'foo','bar']> in C<$elt>
 
 =head1 AUTHOR
 
