@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2012 by Dominique Dumont, Krzysztof Tyszecki.
+# This software is Copyright (c) 2013 by Dominique Dumont, Krzysztof Tyszecki.
 #
 # This is free software, licensed under:
 #
@@ -9,11 +9,11 @@
 #
 package Config::Model::ValueComputer ;
 {
-  $Config::Model::ValueComputer::VERSION = '2.029';
+  $Config::Model::ValueComputer::VERSION = '2.040';
 }
 
-use Any::Moose ;
-use Any::Moose 'X::StrictConstructor' ;
+use Mouse ;
+use MouseX::StrictConstructor;
 use namespace::autoclean;
 
 # use Scalar::Util qw(weaken) ;
@@ -583,7 +583,7 @@ Config::Model::ValueComputer - Provides configuration value computation
 
 =head1 VERSION
 
-version 2.029
+version 2.040
 
 =head1 SYNOPSIS
 
