@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2012 by Dominique Dumont, Krzysztof Tyszecki.
+# This software is Copyright (c) 2013 by Dominique Dumont, Krzysztof Tyszecki.
 #
 # This is free software, licensed under:
 #
@@ -27,11 +27,23 @@
     'element' => [
       'PARTICIPATE',
       {
-        'value_type' => 'enum',
-        'upstream_default' => 'no',
+        'value_type' => 'boolean',
+        'upstream_default' => '0',
         'type' => 'leaf',
         'description' => 'If you don\'t want to participate in the contest, say "no" and we won\'t send messages.',
-        'choice' => [
+        'write_as' => [
+          'no',
+          'yes'
+        ]
+      },
+      'ENCRYPT',
+      {
+        'value_type' => 'boolean',
+        'summary' => 'support for encrypted submissions',
+        'upstream_default' => '0',
+        'type' => 'leaf',
+        'description' => 'encrypt popcon submission. Eventually, this feature wil be enabled by default.',
+        'write_as' => [
           'no',
           'yes'
         ]
@@ -63,11 +75,11 @@ If your MTA is misconfigured or impossible to configure correctly, and it always
       },
       'USEHTTP',
       {
-        'value_type' => 'enum',
-        'upstream_default' => 'yes',
+        'value_type' => 'boolean',
+        'upstream_default' => '1',
         'type' => 'leaf',
         'description' => 'enables http reporting. Set this to \'yes\' to enable it.',
-        'choice' => [
+        'write_as' => [
           'no',
           'yes'
         ]
